Crate re_datafusion

Crate re_datafusion 

The Rerun public data APIs. Access DataFusion TableProviders.

Structs

DataframeQueryTableProvider
DatasetManifestProvider
RedapCatalogProviderList
DataFusion catalog provider list for interacting with Rerun gRPC services.
SearchResultsTableProvider
SegmentTableProvider
TableEntryTableProvider

Enums

TableKind
Underlying provider variant of a table entry.
TableQueryCaller
Where a table scan was initiated from.

Traits

DataframeClientAPI
This trait provides the specific methods used when interacting with the gRPC services for the datafusion client services. By implementing this as a trait we can provide an alternative implementation in our testing facility to remove all gRPC layers and test the server responses more directly.

Functions

query_from_query_expression