DataframeQueryTableProvider

Struct DataframeQueryTableProvider 

pub struct DataframeQueryTableProvider<T: DataframeClientAPI> {
    pub schema: SchemaRef,
    /* private fields */
}

Fields

schema: SchemaRef

Implementations

Source

impl DataframeQueryTableProvider<ConnectionClient>

pub async fn new( origin: Origin, connection: ConnectionRegistryHandle, dataset_id: EntryId, query_expression: &QueryExpression, segment_ids: &[impl AsRef<str> + Sync], index_values: Option<Arc<BTreeMap<String, BTreeSet<IndexValue>>>>, trace_headers: Option<TraceHeaders>, ) -> Result<Self, DataFusionError>

Create a table provider for a gRPC query. This function is async because we need to make gRPC calls to determine the schema at the creation of the table provider.

Source

impl<T: DataframeClientAPI> DataframeQueryTableProvider<T>

pub async fn new_from_client( client: T, dataset_id: EntryId, query_expression: &QueryExpression, segment_ids: &[impl AsRef<str> + Sync], index_values: Option<Arc<BTreeMap<String, BTreeSet<IndexValue>>>>, trace_headers: Option<TraceHeaders>, ) -> Result<Self, DataFusionError>